@@ -58,9 +58,6 @@ class GaussianConditionalIndependenceModel(QuantumCircuit):
         def f(x):  # pylint: disable=invalid-name
             return norm.pdf(x)
 
-        # call super constructor
-        super().__init__(num_qubits, name="P(X)")
-
         # create linear rotations for conditional defaults
         slopes = []
         offsets = []
@@ -81,12 +78,19 @@ class GaussianConditionalIndependenceModel(QuantumCircuit):
 
         # create normal distribution
         normal_distribution = NormalDistribution(
-            n_normal, 0, 1, bounds=(-normal_max_value, normal_max_value)
+            n_normal,
+            0,
+            1,
+            bounds=(-normal_max_value, normal_max_value),
         )
 
         # build circuit
-        self.append(normal_distribution.to_gate(), list(range(n_normal)))
+        inner = QuantumCircuit(num_qubits, name="P(X)")
+        inner.append(normal_distribution.to_gate(), list(range(n_normal)))
         for k, (slope, offset) in enumerate(zip(slopes, offsets)):
             lry = LinearPauliRotations(n_normal, slope, offset)
             qubits = list(range(n_normal)) + [n_normal + k]
-            self.append(lry.to_gate(), qubits)
+            inner.append(lry.to_gate(), qubits)
+
+        super().__init__(num_qubits, name="P(X)")
+        self.append(inner.to_gate(), inner.qubits)
